
#------------------------------------------------------------------------------
# Name          : add_delete_card.tcl
# Author        : 
# Purpose       : Using Virtual Chassis Builder APIs add a Card to Chassis. Fetch Card details from Topology. Delete Cards from Chassis using API. 
# Test Steps    : 1. View Chassis Topology.
#				  2. Add a Card to Chassis.
#                 3. Fetch & View Chassis Topology, Card Details. 
#                 4. Delete the Card from Chassis.     
#
# Prerequisite  : A Chassis & Card is already deployed & reachable.
#------------------------------------------------------------------------------

# You defined Deployed Chassis IP & Deployed Card IP this this file 
source common.tcl
 
#-----------------------------------
# setup path and load IxLoad package
#-----------------------------------
source ../setup_simple.tcl
#Manual
# source "C:/Program Files (x86)/Ixia/IxLoad/8.20.0.206-EB/TclScripts/bin/IxiaWish.tcl"
# package require IxLoad

#-------------------------------------
# Initialize IxLoad
#-------------------------------------

#IxLoad connect should always be called, even for local scripts
# ::IxLoad connect 1.2.3.4

::IxLoad connect $::IxLoadPrivate::SimpleSettings::remoteServer

#--------------------------------------
# setup logger
#--------------------------------------
set logtag "IxLoad-api"
set logName "cbapi_log"
set logger [::IxLoad new ixLogger $logtag 1]
set logEngine [$logger getEngine]
$logEngine setLevels $::ixLogger(kLevelDebug) $::ixLogger(kLevelInfo)
$logEngine setFile $logName 2 256 1

puts "#############################################"
puts "Starting Sample Test : add_delete_card.tcl "
puts "#############################################"

puts "-------------------------------------------------------------"
puts "Conneting to the Chassis : $chassisIP (This Is Your Deployed Chassis IP!)"
puts "--------------------------------------------------------------"
set chassisBuilder [::IxLoad new ixChassisBuilder]
$chassisBuilder connectToChassis  -chassisName $chassisIP
puts $chassisBuilder

puts "Getting Chassis Topology & Card Details.."
set topologies [$chassisBuilder getChassisTopology ]
set count      [$topologies indexCount]
puts "This Chassis has Number of Cards = $count"
if {$count != 0} {
    puts "Deleting all existing cards.."
	for {set index 0} {$index < $count} {incr index} {
		set topology     [$topologies getItem $index]
		puts "topology: $topology"
		set CardServerId     [$topology cget -CardServerId]
		$chassisBuilder deleteCard -cardId $CardServerId
    }
}

puts ""
puts "-------------------------------------------------------"
puts "Add new Card ( $cardIP ) to Chassis with one port & Later Fetch Card Details.."
puts "-------------------------------------------------------"

set CardServerId 1
$chassisBuilder addCard -managementIp $cardIP -cardServerId $CardServerId -keepAliveTimeout 300
set cardId [$chassisBuilder getIxVMCardByIP -managementIp $cardIP]
$chassisBuilder addPort -cardId $CardServerId -portId 1 -interfaceName "eth1" -promiscMode False
$chassisBuilder connectCard -cardId $CardServerId

after 1000

# Check the settings values for new card added.

puts "Getting Details of Added Card.."
set topologies [$chassisBuilder getChassisTopology ]
set count1      [$topologies indexCount]
set index [expr $count1 - 1 ]
set topology     [$topologies getItem $index]
puts "topology: $topology"
set CardServerId     [$topology cget -CardServerId]
set IPAddress        [$topology cget -IPAddress]
set PortServerId     [$topology cget -PortServerId]
puts "CardServerId: $CardServerId"
puts "Card IP Address: $IPAddress"
puts "PortServerId =  $PortServerId"
set topologies      [$chassisBuilder getChassisTopology ]
set after_count           [$topologies indexCount]
puts "Number of Ports Present In This Chassis: $after_count"

# Another way of accessing Card & check Card Status Values

set cardId [$chassisBuilder getIxVMCardByIP -managementIp $cardIP]
set card [$chassisBuilder getCardById -cardId $cardId]
set CardName              [$card cget -CardName]
set CardServerId          [$card cget -CardServerId]
set KeepAliveTimeout      [$card cget -KeepAliveTimeout]
set ManagementIp          [$card cget -ManagementIp]
set Status                [$card cget -Status]
puts "$CardName ID $CardServerId with IP $ManagementIp has the status $Status. Keep Alive Timeout=$KeepAliveTimeout"

after 5000

puts ""
puts "---------------------------------------------"
puts "Delete this Card from Chassis"
puts "---------------------------------------------"

puts "Deleting Card..."
$chassisBuilder deleteCard -cardId $CardServerId
set topologies      [$chassisBuilder getChassisTopology ]
set count           [$topologies indexCount]
if {$count != $after_count -1} {
    error "FAIL - Delete operation is not working; Stop Test"
}
puts "Successfully Deleted Card. There are now $count ports."



#################
#   TEST END    #
#################

::IxLoad disconnect

