
#------------------------------------------------------------------------------
# Name          : chassis_settings.tcl
# Author        : 
# Purpose       : Using Virtual Chassis Builder APIs modify various chassis settings. 
# Test Steps    : 
# 					- View topology
# 					- View Chassis Settings
# 					- Modify Chassis Settings. Set New License Server & NTP Server IP
# 					- Verify that the modifications have been applied     
#
# Prerequisite  : A Chassis is already deployed & At least one discovery credential for host is added.
#-------------------------------------------------------------------------------

# You defined Deployed Chassis IP & Card IP this this file 
source common.tcl

#-----------------------------------
# setup path and load IxLoad package
#-----------------------------------
source ../setup_simple.tcl
#Manual
# source "C:/Program Files (x86)/Ixia/IxLoad/8.20.0.206-EB/TclScripts/bin/IxiaWish.tcl"
# package require IxLoad

#-------------------------------------
# Initialize IxLoad
#-------------------------------------

#IxLoad connect should always be called, even for local scripts
# ::IxLoad connect 1.2.3.4

::IxLoad connect $::IxLoadPrivate::SimpleSettings::remoteServer

#--------------------------------------
# setup logger
#--------------------------------------
set logtag "IxLoad-api"
set logName "cbapi_log"
set logger [::IxLoad new ixLogger $logtag 1]
set logEngine [$logger getEngine]
$logEngine setLevels $::ixLogger(kLevelDebug) $::ixLogger(kLevelInfo)
$logEngine setFile $logName 2 256 1

puts "#############################################"
puts "Starting Sample Test : chassis_settings.tcl "
puts "#############################################"

puts ""
puts "-------------------------------------------------------------"
puts "Conneting to the Chassis : $chassisIP (This Is Your Deployed Chassis IP!)"
puts "--------------------------------------------------------------"

set chassisBuilder [::IxLoad new ixChassisBuilder]
$chassisBuilder connectToChassis  -chassisName $chassisIP
puts $chassisBuilder

# Assuming At least one discovery credential is added in Virtual CB. Else test will fail.

set credentials [$chassisBuilder getDiscoveredCredentials ]
set count    [$credentials indexCount]
set serverInfo     [$credentials getItem 0]

puts "Getting Chassis settings..."
set Enabled        [$serverInfo cget -Enabled]
set ErrorMessage   [$serverInfo cget -ErrorMessage]
set HasError       [$serverInfo cget -HasError]
set ServerName     [$serverInfo cget -ServerName]
set ServerPassword [$serverInfo cget -ServerPassword]
set ServerType     [$serverInfo cget -ServerType]
set ServerUser     [$serverInfo cget -ServerUser]
puts "Enabled = $Enabled"
puts "Error Message = $ErrorMessage"
puts "Has Error = $HasError"
puts "Server Name = $ServerName"
puts "Server Password = $ServerPassword"
puts "Server Type = $ServerType"
puts "Server User = $ServerUser"

puts "Current Chassis Settings.."
puts ".........................."
set chassisSettings     [$chassisBuilder getChassisSettings]
set EnableLicenseCheck  [$chassisSettings cget -EnableLicenseCheck]
set LicenseServer       [$chassisSettings cget -LicenseServer]
set NtpServer           [$chassisSettings cget -NtpServer]
set TxDelay             [$chassisSettings cget -TxDelay]

puts "EnableLicense check = $EnableLicenseCheck"
puts "LicenseServer       = $LicenseServer"
puts "NTP Server          = $NtpServer"
puts "TX Delay            = $TxDelay"

puts ""
puts "-------------------------------------------------------------"
puts "Modifying Chassis Setting & Displaying new settings.."
puts "--------------------------------------------------------------"

puts "Modifying Chassis Settings\n"
$chassisSettings cset -LicenseServer "10.216.116.104"
$chassisSettings cset -NtpServer "10.216.102.206"
$chassisSettings cset -TxDelay 10

$chassisBuilder setChassisSettings -chassisSettings $chassisSettings

puts "Displaying the new chassis settings\n"
set chassisSettings2     [$chassisBuilder getChassisSettings]
set EnableLicenseCheck2  [$chassisSettings2 cget -EnableLicenseCheck]
set LicenseServer2       [$chassisSettings2 cget -LicenseServer]
set NtpServer2           [$chassisSettings2 cget -NtpServer]
set TxDelay2             [$chassisSettings2 cget -TxDelay]

puts "EnableLicense check = $EnableLicenseCheck2"
puts "LicenseServer       = $LicenseServer2"
puts "NTP Server          = $NtpServer2"
puts "TX Delay            = $TxDelay2"


#################
#   TEST END    #
#################

::IxLoad disconnect
