#############################################################################################
#   Version 8.50
#   
#   File: ixTclHalRt.tcl
#
#  Package initialization file
#
#  This file is executed when you use "package require IxRt" to
#  load the IxTclHalRt library package.  It sets up the IXTCLHAL_LIBRARY
#  environment variable to point to the directory where the package
#  resides.
#
#  If the package is being loaded from a multi-user template script, then continue
#  otherwise return rightaway
#
#   Copyright (c) 2015  IXIA.
#	All Rights Reserved.
#
#############################################################################################

## basically this is a keeping room for all the method pointer stuff + ixTclHal package req procs

# TODO: This code is extracted from "TclScripts/lib/ixTcl1.0/ixTclHalSetup.tcl"
#       and should be made into a module so that it can be invoked for other packages
#       that may be created in the future.

package req IxTclHal

set ixRtCmds { rt rtStatus }

if {$tcl_platform(platform) == "windows"} \
{ 
	load IxTclHal.dll Rt
} else \
{ 
    # This extracts the absolute path of this script. Its purpose is to differentiate between native                                                                                                                                                                            
    # IxTCLHAL package under Unix and platform independent TCL (the TCL client which communicates with TCLServer)                                                                                                                                                               
    set absolutePath    [ dict get [ info frame [ info frame ] ] file ]                                                                                                                                                                                                         
    # Denotes support for IxTCLHAL package under Unix (search for the install path) 
    set installLocation [file normalize /opt/ixia/ixos/]
    set nativeTCLUnix   [string match *$installLocation/* $absolutePath]    
                                                                                                                                                                                                                                                                                
    # Try to see if we are in dev environment. If so, mark it appropriately                                                                                                                                                                                                     
    # In order to work from your dev machine, you can set this variable before starting tclsh:                                                                                                                                                                                  
    # export IXIA_TCL_DEV=1 (for example)                                                                                                                                                                                                                                       
    if {[info exists ::env(IXIA_TCL_DEV)]} {                                                                                                                                                                                                                                    
        set nativeTCLUnix 1                                                                                                                                                                                                                                                     
    }                                                                                                                                                                                                                                                                           
                                                                                                                                                                                                                                                                                
    # Load the Unix IxTCLHAL library                                                                                                                                                                                                                                            
    if {$nativeTCLUnix == 1} {                                                                                                                                                                                                                                                  
        set ixtcl10Folder [string range $absolutePath 0 [string last / $absolutePath]]                                                                                                                                                                                          
        load "$ixtcl10Folder../../../libixtclhal.so" Rt                                                                                                                                                                                                                           
    } else {
        # IxOS PIT 
        if {[tclServer::isTclServerConnected]} {
            # intercept ixTclServices commands, send to remote side for execution:
            remoteDefine $ixRtCmds
            # Make sure the remote end knows what to do with those commands:
            if [catch {clientSend $ixTclSvrHandle "package req IxRt"} result] {
                puts "Error installing IxRt on remote end: "
                puts $result
                return 1
            }
        } else {
            puts "Error installing IxRt on remote end, must be connected to ixTclServer."
            return 1
        }
    }
}

package provide IxRt 8.50

ixTclHal::createCommandPtr TCLRtStatus rtStatus
ixTclHal::createCommand TCLRt   rt  \$::rtStatusPtr

